<?php

/**
 * @file
 * The Choice CMS Initial Screen Settings functionality.
 */

/**
 * Quantcast Choice CMS Admin Settings Form.
 *
 * Purpose Screen Settings Form.
 *
 * @param $form
 *   An array contianing the form settings and field settings.
 * @param $form_state
 *   An associative array containing the current state of the form.
 * @param $lang
 *   A string that contains the arg(4) element from the url, passed in from choice_cms_menu()
 * @return
 *   Drupal Form Array
 */
function choice_cms_settings_initial_screen_form( $form, &$form_state, $lang ) {

  // Get the currently active Choice CMS items
  $active_languages = variable_get( 'choice_lang_active', array() );
  $lang = strtolower( $lang );

  // Initial form definition.
  $form = array(
    '#attributes' => array(
      'class'     => array(
        'initial-screen-form',
        'choice-cms',
        'waiting-for-values',
      ),
      'data-choice-lang' => strtolower( $lang ),
    ),
    '#attached'  => array(
      'js'       => array(
        drupal_get_path( 'module', 'choice_cms' ) . '/js/admin/choice-cms.admin.min.js',
      )
    ),
  );

  // Add the form header section.
  $form['top'] = array(
    '#type'   => 'markup',
    '#markup' => '
      <div class="form-header">
        <h2>Initial Screen Settings - ' . strtoupper( $lang ) . '</h2>
      </div>
    ',
    '#weight' => -1,
  );

  // If there are no active Choice CMS languages.
  if ( empty( $active_languages ) ) {

    // Add a message for display.
    $form['msg'] = array(
      '#type'   => 'markup',
      '#markup' => "<p>" . t( "You don't have any active Choice CMS languages selected." ) . "</p><p>" . t( "Head over to the <a href='@url'>Choice CMS General Settings</a> and activate your languages", array( "@url" => url( "/admin/config/choice-cms/general", array("fragment" => "edit-choice-lang" ) ) ) ) . "</p>",
      '#weight' => 2,
    );

    // Return the form with the no active languages message..
    return $form;

  }

  // The user has active languages, however the current page attempting to be viewed is not one of those active languages.
  elseif ( ! in_array( $lang, $active_languages, TRUE ) )  {

    $form['msg'] = array(
      '#type'   => 'markup',
      '#markup' => '<p>' . t( "@lang is not an active Choice CMS language.", array( '@lang' => strtoupper( $lang ) ) ) . '</p><p>' . t( 'Inactive Choice CMS languages can be activated on the <a href="@url">General Settings</a> page.', array( '@url' => url( '/admin/config/choice-cms/general', array('fragment' => 'edit-choice-lang' ) ) ) ) . '</p>',
      '#weight' => 2,
    );

    // The language being viewed is not an active language, return the form.
    return $form;

  }

  //////
  // The user is viewing a language settings page of a currently active Choice CMS language.
  // - Build the plugin settings for the initial screen.
  /////

  // Get the currently stored values.
  $choice_initial_screen_title              = variable_get( 'choice_initial_screen_title', json_encode( array() ) );
  $choice_initial_screen_body               = variable_get( 'choice_initial_screen_body', json_encode( array() ) );
  $choice_initial_screen_reject             = variable_get( 'choice_initial_screen_reject', json_encode( array() ) );
  $choice_initial_screen_no_option          = variable_get( 'choice_initial_screen_no_option', json_encode( array() ) );
  $choice_initial_screen_accept             = variable_get( 'choice_initial_screen_accept', json_encode( array() ) );
  $choice_initial_screen_purpose            = variable_get( 'choice_initial_screen_purpose', json_encode( array() ) );
  $choice_initial_screen_custom_link_1_text = variable_get( 'choice_initial_screen_custom_link_1_text', json_encode( array() ) );
  $choice_initial_screen_custom_link_1_url  = variable_get( 'choice_initial_screen_custom_link_1_url', json_encode( array() ) );
  $choice_initial_screen_custom_link_2_text = variable_get( 'choice_initial_screen_custom_link_2_text', json_encode( array() ) );
  $choice_initial_screen_custom_link_2_url  = variable_get( 'choice_initial_screen_custom_link_2_url', json_encode( array() ) );

  // Decode the json returned from the above variable_get calls.
  $choice_initial_screen_title              = isset( $choice_initial_screen_title ) && ! empty( $choice_initial_screen_title ) ? json_decode( $choice_initial_screen_title, TRUE ) : array();
  $choice_initial_screen_body               = isset( $choice_initial_screen_body ) && ! empty( $choice_initial_screen_body ) ? json_decode( $choice_initial_screen_body, TRUE ) : array();
  $choice_initial_screen_reject             = isset( $choice_initial_screen_reject ) && ! empty( $choice_initial_screen_reject ) ? json_decode( $choice_initial_screen_reject, TRUE ) : array();
  $choice_initial_screen_no_option          = isset( $choice_initial_screen_no_option ) && ! empty( $choice_initial_screen_no_option ) ? json_decode( $choice_initial_screen_no_option, TRUE ) : array();
  $choice_initial_screen_accept             = isset( $choice_initial_screen_accept ) && ! empty( $choice_initial_screen_accept ) ? json_decode( $choice_initial_screen_accept, TRUE ) : array();
  $choice_initial_screen_purpose            = isset( $choice_initial_screen_purpose ) && ! empty( $choice_initial_screen_purpose ) ? json_decode( $choice_initial_screen_purpose, TRUE ) : array();
  $choice_initial_screen_custom_link_1_text = isset( $choice_initial_screen_custom_link_1_text ) && ! empty( $choice_initial_screen_custom_link_1_text ) ? json_decode( $choice_initial_screen_custom_link_1_text, TRUE ) : array();
  $choice_initial_screen_custom_link_1_url  = isset( $choice_initial_screen_custom_link_1_url ) && ! empty( $choice_initial_screen_custom_link_1_url ) ? json_decode( $choice_initial_screen_custom_link_1_url, TRUE ) : array();
  $choice_initial_screen_custom_link_2_text = isset( $choice_initial_screen_custom_link_2_text ) && ! empty( $choice_initial_screen_custom_link_2_text ) ? json_decode( $choice_initial_screen_custom_link_2_text, TRUE ) : array();
  $choice_initial_screen_custom_link_2_url  = isset( $choice_initial_screen_custom_link_2_url ) && ! empty( $choice_initial_screen_custom_link_2_url ) ? json_decode( $choice_initial_screen_custom_link_2_url, TRUE ) : array();

  // Add a loader to give the user feedback when the form is waiting for data.
  $form['loader'] = array(
    '#type'          => 'markup',
    '#markup'        => '<div class="loader"></div>',
    '#weight'        => -999,
  );

  // Add the current language to the form as a hidden field.
  $form['choice_initial_screen']['lang'] = array(
    '#type'          => 'hidden',
    '#default_value' => $lang,
    '#weight'        => -100,
  );

  // Add Initial Screen Title.
  $form['choice_initial_screen']['title'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Title Text' ),
    '#description'   => t( 'The title text on the initial global consent screen to be displayed in the ui.' ),
    '#default_value' => isset( $choice_initial_screen_title[$lang] ) ? $choice_initial_screen_title[$lang] : '',
    '#required'      => TRUE,
    '#field_suffix'  => '',
    '#weight'        => 5,
  );

  // Add Intial Screen Body Text.
  $form['choice_initial_screen']['body'] = array(
    '#type'          => 'radios',
    '#title'         => t( 'Body Text' ),
    '#description'   => t( 'The main body text on the initial global consent screen to be displayed in the ui.' ),
    '#options'       => get_init_screen_body_options( $lang ),
    /*
    '#options'       => array(
      '1'            => t( 'We and our partners use technology such as cookies on our site to personalise content and ads, provide social media features, and analyse our traffic. Click below to consent to the use of this technology across the web. You can change your mind and change your consent choices at anytime by returning to this site.' ),
      '2'            => t( 'We and our partners process your personal data using technology such as cookies in order to serve advertising, analyse our traffic and deliver customised experiences for you. You have choice in who uses your data and for what purposes and after setting your preferences may come back anytime to make changes.' ),
      '3'            => t( 'The quality content and information we provide to you depends on the revenue we generate from advertising. We and our partners use your personal data in order to serve personalised advertising, measure activity on the site and deliver personalised features and content to you. Click below to consent to the use of your data. You can revisit your choices at any time.' ),
    ),
    */
    '#default_value' => isset( $choice_initial_screen_body[$lang] ) ? $choice_initial_screen_body[$lang] : array(),
    '#required'      => TRUE,
    '#field_suffix'  => '',
    '#weight'        => 10,
  );

  // Add Initial Screen Non Option.
  $form['choice_initial_screen']['no_option'] = array(
    '#type'          => 'select',
    '#title'         => t( 'Reject All Button Option' ),
    '#description'   => t( 'Determines if the the reject consent button will be displayed on the initial global consent page.' ),
    '#default_value' => isset( $choice_initial_screen_no_option[$lang] ) ? $choice_initial_screen_no_option[$lang] : array(),
    '#options'       => array(
      'false'           => t( 'Do not display the Reject All Consent button on the initial screen.'),
      'true'            => t( 'Display the Reject All Consent button on the initial screen.'),
    ),
    '#required'      => TRUE,
    '#field_suffix'  => '',
    '#weight'        => 15,
  );

  // Add Initial Screen Reject Button Text.
  $form['choice_initial_screen']['reject'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Reject Button Text' ),
    '#description'   => t( 'The reject consent button text on the initial global consent screen to be displayed in the ui.' ),
    '#default_value' => isset( $choice_initial_screen_reject[$lang] ) ? $choice_initial_screen_reject[$lang] : '',
    '#required'      => FALSE,
    '#field_suffix'  => '',
    '#weight'        => 20,
    '#attributes'    => array(
      'class'          => array(
        'custom-class-here'
      )
    ),
    '#states' => array(
      'visible' => array(
        ':input[name="no_option"]' => array(
          'value' => 'true'
        )
      ),
    ),
  );

  // Add Initial Screen Accept Button Text.
  $form['choice_initial_screen']['accept'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Accept Button Text' ),
    '#description'   => t( 'The accept consent button text on the initial global consent screen to be displayed in the ui.' ),
    '#default_value' => isset( $choice_initial_screen_accept[$lang] ) ? $choice_initial_screen_accept[$lang] : '',
    '#required'      => TRUE,
    '#field_suffix'  => '',
    '#weight'        => 25,
  );

  // Add Initial Screen Purpose Link Text.
  $form['choice_initial_screen']['purpose'] = array(
    '#type'          => 'textfield', //you can find a list of available types in the form api
    '#title'         => t( 'Initial Screen Purpose Link Text' ),
    '#description'   => t( 'The purpose link text on the initial global consent screen to be displayed in the ui. When clicked, the ui updates to display the purpose consent screen.' ),
    '#default_value' => isset( $choice_initial_screen_purpose[$lang] ) ? $choice_initial_screen_purpose[$lang] : '',
    '#required'      => TRUE,
    '#field_suffix'  => '',
    '#weight'        => 30,
  );

  // Add custom link fieldset.
  $form['choice_initial_screen']['custom_links'] = array(
    '#type'        => 'fieldset',
    '#title'       => t( 'Initial Screen Custom Links' ),
    '#description' => t( 'Initial Screen custom links are displayed at the bottom of the of the initial screen UI.' ),
    '#weight'      => 35,
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );

  // Add custom link 1 fieldset.
  $form['choice_initial_screen']['custom_links']['1'] = array(
    '#type'        => 'fieldset',
    '#title'       => t( 'Initial Screen Custom Link 1' ),
    '#weight'      => 5,
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
  );

  // Add Initial Screen Purpose Link Text.
  $form['choice_initial_screen']['custom_links']['1']['text_1'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Custom Link 1 Text' ),
    '#description'   => t( 'Add a custom link to the initial screen.' ),
    '#default_value' => isset( $choice_initial_screen_custom_link_1_text[$lang] ) ? $choice_initial_screen_custom_link_1_text[$lang] : '',
    '#required'      => FALSE,
    '#field_suffix'  => '',
    '#weight'        => 5,
  );

  // Add Initial Screen Purpose Link Text.
  $form['choice_initial_screen']['custom_links']['1']['url_1'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Custom Link 1 URL' ),
    '#description'   => t( 'Add a custom link to the initial screen.' ),
    '#default_value' => variable_get( 'choice_initial_screen_custom_link_1_url', '' ),
    '#default_value' => isset( $choice_initial_screen_custom_link_1_url[$lang] ) ? $choice_initial_screen_custom_link_1_url[$lang] : '',
    '#required'      => FALSE,
    '#field_suffix'  => '',
    '#weight'        => 5,
  );

  // Add custom link 2 fieldset
  $form['choice_initial_screen']['custom_links']['2'] = array(
    '#type'        => 'fieldset',
    '#title'       => t( 'Initial Screen Custom Link 2' ),
    '#weight'      => 5,
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
  );

  // Add Initial Screen Purpose Link Text.
  $form['choice_initial_screen']['custom_links']['2']['text_2'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Custom Link 2 Text' ),
    '#description'   => t( 'Add a custom link to the initial screen.' ),
    '#default_value' => isset( $choice_initial_screen_custom_link_2_text[$lang] ) ? $choice_initial_screen_custom_link_2_text[$lang] : '',
    '#required'      => FALSE,
    '#field_suffix'  => '',
    '#weight'        => 5,
  );

  // Add Initial Screen Purpose Link Text.
  $form['choice_initial_screen']['custom_links']['2']['url_2'] = array(
    '#type'          => 'textfield',
    '#title'         => t( 'Initial Screen Custom Link 2 URL' ),
    '#description'   => t( 'Add a custom link to the initial screen.' ),
    '#default_value' => isset( $choice_initial_screen_custom_link_2_url[$lang] ) ? $choice_initial_screen_custom_link_2_url[$lang] : '',
    '#required'      => FALSE,
    '#field_suffix'  => '',
    '#weight'        => 10,
  );

  // Add the form submit button.
  $form['submit_button'] = array(
    '#type'   => 'submit',
    '#value'  => t( 'Update Initial Screen Settings' ) . ' - ' . strtoupper( $lang ),
    '#weight' => 100,
  );

  return $form;

}

/**
 * Implements hook_validate().
 */
function choice_cms_settings_initial_screen_form_validate( $form, &$form_state ) {

  // Get all of the submitted values.
  $values = $form_state['values'];

  // If the 'Reject All Button Option' field is set to TRUE, make the 'Initial Screen Reject Button Text' field required by check if it is empty.
  if ( $values['reject'] == '' && $values['no_option'] == 'true' ) {
    form_set_error( 'reject', t( "If the 'Reject All Button Option' field is set to 'Display the Reject All Consent button on the initial screen.', the 'Initial Screen Reject Button Text' field cannot be empty." ) );
  }

}

/**
 * Implements hook_submit().
 */
function choice_cms_settings_initial_screen_form_submit( $form, &$form_state ) {

  $active_languages = variable_get( 'choice_lang_active', array() );
  $values           = isset( $form_state['values'] ) && ! empty( isset( $form_state['values'] ) ) ? $form_state['values'] : array();

  // Get the current stored values for the initial screen
  $current_choice_initial_screen_title                = json_decode( variable_get( 'choice_initial_screen_title', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_body                 = json_decode( variable_get( 'choice_initial_screen_body', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_reject               = json_decode( variable_get( 'choice_initial_screen_reject', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_no_option            = json_decode( variable_get( 'choice_initial_screen_no_option', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_accept               = json_decode( variable_get( 'choice_initial_screen_accept', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_purpose              = json_decode( variable_get( 'choice_initial_screen_purpose', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_custom_link_1_text   = json_decode( variable_get( 'choice_initial_screen_custom_link_1_text', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_custom_link_1_url    = json_decode( variable_get( 'choice_initial_screen_custom_link_1_url', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_custom_link_2_text   = json_decode( variable_get( 'choice_initial_screen_custom_link_2_text', json_encode( array() ) ), TRUE );
  $current_choice_initial_screen_custom_link_2_url    = json_decode( variable_get( 'choice_initial_screen_custom_link_2_url', json_encode( array() ) ), TRUE );

  // Get the values submitted for the intitial screen form
  $lang                                               = isset( $values['lang'] )      ? $values['lang']      : '';
  $submitted_choice_initial_screen_title              = isset( $values['title'] )     ? $values['title']     : '';
  $submitted_choice_initial_screen_body               = isset( $values['body'] )      ? $values['body']      : '';
  $submitted_choice_initial_screen_reject             = isset( $values['reject'] )    ? $values['reject']    : '';
  $submitted_choice_initial_screen_no_option          = isset( $values['no_option'] ) ? $values['no_option'] : '';
  $submitted_choice_initial_screen_accept             = isset( $values['accept'] )    ? $values['accept']    : '';
  $submitted_choice_initial_screen_purpose            = isset( $values['purpose'] )   ? $values['purpose']   : '';
  $submitted_choice_initial_screen_custom_link_1_text = isset( $values['text_1'] )    ? $values['text_1']    : '';
  $submitted_choice_initial_screen_custom_link_1_url  = isset( $values['url_1'] )     ? $values['url_1']     : '';
  $submitted_choice_initial_screen_custom_link_2_text = isset( $values['text_2'] )    ? $values['text_2']    : '';
  $submitted_choice_initial_screen_custom_link_2_url  = isset( $values['url_2'] )     ? $values['url_2']     : '';

  // Only save values if the language being saved is an active language.
  if ( in_array( strtolower( $lang ), $active_languages ) )  {

    // Update the current values, for the specific language submitted.
    // Encode the array into json and save the field data.
    $current_choice_initial_screen_title[$lang] = $submitted_choice_initial_screen_title;
    variable_set('choice_initial_screen_title', json_encode( $current_choice_initial_screen_title ) );

    $current_choice_initial_screen_body[$lang] = $submitted_choice_initial_screen_body;
    variable_set('choice_initial_screen_body', json_encode( $current_choice_initial_screen_body ) );

    $current_choice_initial_screen_reject[$lang] = $submitted_choice_initial_screen_reject;
    variable_set('choice_initial_screen_reject', json_encode( $current_choice_initial_screen_reject ) );

    $current_choice_initial_screen_no_option[$lang] = $submitted_choice_initial_screen_no_option;
    variable_set('choice_initial_screen_no_option', json_encode( $current_choice_initial_screen_no_option ) );

    $current_choice_initial_screen_accept[$lang] = $submitted_choice_initial_screen_accept;
    variable_set('choice_initial_screen_accept', json_encode( $current_choice_initial_screen_accept ) );

    $current_choice_initial_screen_purpose[$lang] = $submitted_choice_initial_screen_purpose;
    variable_set('choice_initial_screen_purpose', json_encode( $current_choice_initial_screen_purpose ) );

    $current_choice_initial_screen_custom_link_1_text[$lang] = $submitted_choice_initial_screen_custom_link_1_text;
    variable_set('choice_initial_screen_custom_link_1_text', json_encode( $current_choice_initial_screen_custom_link_1_text ) );

    $current_choice_initial_screen_custom_link_1_url[$lang] = $submitted_choice_initial_screen_custom_link_1_url;
    variable_set('choice_initial_screen_custom_link_1_url', json_encode( $current_choice_initial_screen_custom_link_1_url ) );

    $current_choice_initial_screen_custom_link_2_text[$lang] = $submitted_choice_initial_screen_custom_link_2_text;
    variable_set('choice_initial_screen_custom_link_2_text', json_encode( $current_choice_initial_screen_custom_link_2_text) );

    $current_choice_initial_screen_custom_link_2_url[$lang] = $submitted_choice_initial_screen_custom_link_2_url;
    variable_set('choice_initial_screen_custom_link_2_url', json_encode( $current_choice_initial_screen_custom_link_2_url ) );

  }

}

/**
 * Return the initial screen body text options array.
 *
 * @since 1.0.0
 */
function get_init_screen_body_options( $lang = 'en' ) {
  $ret = array();
  $body_options = array();

  // English.
  $body_options['en'] = array(
    '1' => 'We and our partners use technology such as cookies on our site to personalise content and ads, provide social media features, and analyse our traffic. Click below to consent to the use of this technology across the web. You can change your mind and change your consent choices at anytime by returning to this site.',
    '2' => 'We and our partners process your personal data using technology such as cookies in order to serve advertising, analyse our traffic and deliver customised experiences for you. You have choice in who uses your data and for what purposes and after setting your preferences may come back anytime to make changes.',
    '3' => 'The quality content and information we provide to you depends on the revenue we generate from advertising. We and our partners use your personal data in order to serve personalised advertising, measure activity on the site and deliver personalised features and content to you. Click below to consent to the use of your data. You can revisit your choices at any time.',
  );
  // French.
  $body_options['fr'] = array(
    '1' => 'Nos partenaires et nous-mêmes utilisons différentes technologies, telles que les cookies, pour personnaliser les contenus et les publicités, proposer des fonctionnalités sur les réseaux sociaux et analyser le trafic. Merci de cliquer sur le bouton ci-dessous pour donner votre accord. Vous pouvez changer d’avis et modifier vos choix à tout moment.',
    '2' => 'Nos partenaires et nous-mêmes traitons vos données personnelles afin de vous montrer de la publicité, comprendre notre audience et offrir une expérience utilisateur personnalisée. Vous pouvez choisir qui utilise vos données personnelles et dans quel but. Vous pouvez également faire le choix à tout moment de modifier vos réglages en matière de cookies.',
    '3' => 'La qualité du contenu et les informations que nous vous apportons dépend du revenue généré par la publicité. Nos partenaires et nous-mêmes recueillons et traitons vos données personnelles afin de proposer de la publicité personnalisée, analyser l’activité sur le site et offrir des fonctionnalités ainsi que du contenu personnalisé. Cliquez ci-dessous pour accepter l’utilisation des données. Vous pouvez faire le choix à tout moment de modifier vos réglages en matière de cookies.',
  );
  // German.
  $body_options['de'] = array(
    '1' => 'Wir und unsere Partner nutzen auf unserer Website Technologien wie beispielsweise Cookies, um Inhalte und Werbung zu personalisieren, Social-Media-Funktionen anzubieten und den Website-Traffic zu analysieren. Durch einen Klick auf die untenstehende Schaltfläche stimmen Sie dem Einsatz dieser Technologie im gesamten Internet zu. Sie können diese Einwilligung jederzeit überarbeiten oder zurücknehmen, indem Sie auf diese Website zurückkehren.',
    '2' => 'Wir und unsere Partner verarbeiten Ihre persönlichen Daten auf der Basis von Technologien wie Cookies, um Ihnen Werbung auszuspielen, den Traffic zu analysieren und personalisierte Inhalte anzuzeigen. Sie haben die Wahl, welche Partner Ihre Daten für welche Zwecke nutzen dürfen. Nach der Auswahl Ihrer Präferenzen können Sie diese jederzeit bearbeiten, indem Sie auf diese Website zurückkehren.',
    '3' => 'Die Inhalte und Informationen, die wir Ihnen zur Verfügung stellen, werden durch die Einnahmen  finanziert, die wir durch Werbung generieren. Wir und unsere Partner nutzen Ihre persönlichen Daten, um Ihnen personalisierte Werbung anzuzeigen, Aktivitäten auf unserer Website zu analysieren und Ihnen personalisierte Funktionalitäten sowie Inhalte anzubieten. Durch einen Klick auf die untenstehende Schaltfläche können Sie der Nutzung Ihrer Daten zustimmen. Sie haben jederzeit die Möglichkeit, Ihre Entscheidung zu ändern.',
  );
  // Italian.
  $body_options['it'] = array(
    '1' => "Noi e i nostri partner utilizziamo, sul nostro sito, tecnologie come i cookie per personalizzare contenuti e annunci, fornire funzionalità per social media e analizzare il nostro traffico. Facendo clic di seguito si acconsente all'utilizzo di questa tecnologia. Puoi cambiare idea e modificare le tue scelte sul consenso in qualsiasi momento ritornando su questo sito.",
    '2' => "Noi e i nostri partner processiamo i tuoi dati personali utilizzando tecnologie, come i cookie, per erogare pubblicità, analizzare il nostro traffico e fornire all'utente un'esperienza di navigazione personalizzata. Hai la possibilità di scegliere chi utilizza i tuoi dati e per quali scopi, dopo aver impostato le tue preferenze puoi tornare in qualsiasi momento per apportare modifiche.",
    '3' => "La qualità del contenuto e delle informazioni che forniamo dipendono dai ricavi generati dalla pubblicità. Noi e i nostri partner raccogliamo e processiamo i tuoi dati personali per erogare pubblicità personalizzata, analizzare l'attività sul nostro sito e fornire funzionalità e contenuti personalizzati. Facendo clic di seguito si acconsente all'utilizzo dei tuoi dati. Puoi modificare le tue scelte in qualsiasi momento.",
  );
  // Spansih.
  $body_options['es'] = array(
    '1' => 'Tanto nuestros partners como nosotros utilizamos cookies en nuestro sitio web para personalizar contenido y publicidad, proporcionar funcionalidades a las redes sociales, o analizar nuestro tráfico. Haciendo click consientes el uso de esta tecnologia en nuestra web. Puedes cambiar de opinion y personalizar tu consentimiento siempre que quieras volviendo a esta web',
    '2' => 'Tanto nuestros partners como nosotros procesamos tu información personal como las cookies para hacer publicidad, analizar nuestro tráfico y proporcionar experiencias personalizadas en tu navegación. Tu tienes el control sobre quién utiliza tu información personal y para que propósitos. Una vez has configurado tus preferencias puedes volver siempre que quieras para realizar cualquier cambio.',
    '3' => 'El contenido de calidad e información que proporcionamos depende de los ingresos que generamos por publicidad. Tanto nuestros partners como nosotros utilizamos tu información personal (cookies) con el propósito de server publicidad personalizada, medir la actividad del sitio web y proporcionar contenido y funcionalidades personalizadas para ti. Haz click a continuación para aceptar el uso de tu información personal (cookies). Puedes revisar este consentimiento siempre que quieras.',
  );
  // Danish.
  $body_options['da'] = array(
    '1' => 'Vi og vores partnere bruger teknologi, f.eks. cookies, på vores websted, til at tilpasse indhold og annoncer, levere funktioner til sociale medier og analysere vores trafik. Klik nedenfor for at acceptere brugen af denne teknologi på webstedet. Hvis du skifter mening, kan du når som helst trække din accept tilbage ved at vende tilbage til dette websted.',
    '2' => 'Vi og vores partnere behandler dine persondata ved hjælp af teknologi, f.eks. cookies, med henblik på at levere annoncer, analysere trafik og levere tilpassede oplevelser til dig. Du har indflydelse på, hvem der må bruge dine data, og til hvilke formål, og du kan når som helst vende tilbage og ændre dine indstillinger.',
    '3' => 'Kvaliteten af det indhold og de oplysninger, vi leverer til dig, afhænger at vores annonceomsætning. Vi og vores partnere bruger dine persondata til at levere tilpasset annoncering, måle aktivitet på webstedet og levere tilpassede funktioner og indhold til dig. Klik nedenfor for at acceptere, at vi bruger dine data. Du kan når som helst ændre dine valg.',
  );
  // Dutch.
  $body_options['nl'] = array(
    '1' => 'Wij en onze partners gebruiken technologie op onze site, zoals cookies om inhoud en advertenties te personaliseren, social media functies te bieden en ons websiteverkeer te analyseren. Klik hieronder om akkoord te gaan met het gebruik van deze technologie op het internet. U kunt op elk moment van gedachten veranderen en uw instemmingskeuzes wijzigen door terug te keren naar deze site.',
    '2' => 'Wij en onze partners verwerken uw persoonlijke gegevens met behulp van technologie zoals cookies om advertenties weer te geven, ons verkeer te analyseren en op maat gemaakte ervaringen voor u te leveren. U hebt de keuze wie uw gegevens gebruikt en voor welke doeleinden en na het instellen van uw voorkeuren kunt u op elk moment terugkomen om wijzigingen aan te brengen.',
    '3' => 'De kwaliteit van de inhoud en informatie die we u verstrekken, is afhankelijk van de inkomsten die we genereren uit advertenties. Wij en onze partners gebruiken uw persoonlijke gegevens om gepersonaliseerde reclame te bieden, activiteiten op de site te meten en gepersonaliseerde functies en inhoud aan u te leveren. Klik hieronder om toestemming te geven voor het gebruik van uw gegevens. U kunt uw keuzes op elk gewenst moment opnieuw bekijken.',
  );
  // Greek.
  $body_options['el'] = array(
    '1' => 'Τόσο εμείς όσο και οι συνεργάτες μας χρησιμοποιούμε τεχνολογία όπως τα cookies στον ιστότοπό μας, για εξατομίκευση περιεχομένου και διαφημίσεων, παροχή λειτουργιών μέσων κοινωνικής δικτύωσης και ανάλυση των δεδομένων επισκεπτών μας. Κάντε κλικ παρακάτω για να επιβεβαιώσετε ότι συμφωνείτε με τη χρήση αυτής της τεχνολογίας στο web. Οποιαδήποτε στιγμή, μπορείτε να αλλάξετε γνώμη και να αλλάξετε επιλογές συγκατάθεσης, επιστρέφοντας σε αυτό τον ιστότοπο.',
    '2' => 'Τόσο εμείς όσο και οι συνεργάτες μας επεξεργαζόμαστε τα προσωπικά δεδομένα σας με τεχνολογία όπως τα cookies, ώστε να παρουσιάζουμε διαφημίσεις, να αναλύουμε τα δεδομένα επισκεπτών μας και να σας παρέχουμε εξατομικευμένη εμπειρία. Έχετε τον έλεγχο ως προς το ποιος θα χρησιμοποιεί τα δεδομένα σας και για ποιους σκοπούς και, αφού ορίσετε τις προτιμήσεις σας, θα μπορείτε να επανέρχεστε για να κάνετε αλλαγές.',
    '3' => 'Το ποιοτικό περιεχόμενο και οι πληροφορίες που σας παρέχουμε εξαρτώνται από τα έσοδα που αποκομίζουμε από διαφημίσεις. Τόσο εμείς όσο και οι συνεργάτες μας χρησιμοποιούμε τα προσωπικά δεδομένα σας για να παρέχουμε διαφημίσεις, να αναλύουμε τα δεδομένα επισκεπτών μας, να μετράμε τη δραστηριότητα στον ιστότοπο και να σας παρέχουμε εξατομικευμένες λειτουργίες και περιεχόμενο. Κάντε κλικ παρακάτω για να επιβεβαιώσετε ότι συμφωνείτε με τη χρήση των δεδομένων σας. Μπορείτε να αναθεωρήσετε τις επιλογές σας ανά πάσα στιγμή.',
  );
  // Hungarian.
  $body_options['hu'] = array(
    '1' => 'Annak érdekében, hogy személyre szabjuk a tartalmakat és hirdetéseket, közösségi média szolgáltatásokat nyújtsunk, valamint elemezzük látogatottságunkat, partnereinkkel együtt különböző technológiákat, például sütiket (cookie-kat) használunk oldalunkon. Kattintson az alábbi gombra ezen technológia webes használatának elfogadásához. Bármikor meggondolhatja magát, és erre az oldalra visszatérve megváltoztathatja hozzájárulási beállításait.',
    '2' => 'Személyes adatait vállalatunk és partnerei hirdetési célokból, látogatottságunk elemzéséhez, valamint személyre szabott élmények nyújtása érdekében kezelik a sütikhez hasonló technológiák felhasználásával. Kiválaszthatja, hogy ki és milyen célokra használhatja adatait, preferenciáinak beállítása után pedig bármikor visszatérhet, hogy megváltoztassa azokat.',
    '3' => 'Az Önnek nyújtott minőségi tartalom és információ feltétele a hirdetésekből szerzett bevételünk. Partnereinkkel együtt arra használjuk fel az Ön személyes adatait, hogy személyre szabott hirdetéseket biztosíthassunk, mérjük az aktivitást az oldalon, valamint személyre szabott szolgáltatásokat és tartalmakat nyújtsunk Önnek. Kattintson az alábbi gombra adatai használatának elfogadásához. Bármikor visszatérhet választásaihoz.',
  );
  // Portuguese.
  $body_options['pt'] = array(
    '1' => 'Nós e os nossos parceiros utilizamos determinadas tecnologias no nosso site, como os cookies, para personalizarmos os conteúdos e a publicidade, proporcionarmos funcionalidades das redes sociais e analisarmos o nosso tráfego. Clique em baixo para consentir a utilização destas tecnologias na web. Pode mudar de ideias e alterar as suas opções de consentimento em qualquer momento voltando a este site.',
    '2' => 'Nós e os nossos parceiros processamos os seus dados pessoais através de tecnologias, como os cookies, para sabermos qual é a melhor publicidade para si, para analisarmos o nosso tráfego e para lhe proporcionarmos uma experiência personalizada. Pode optar por indicar quem pode utilizar os seus dados e os objetivos da utilização dos mesmos e, depois de definir as suas preferências, pode voltar em qualquer altura para fazer alterações.',
    '3' => 'A qualidade dos conteúdos e das informações que lhe fornecemos depende das receitas que geramos com a publicidade. Nós e os nossos parceiros utilizamos os seus dados pessoais para lhe podermos mostrar a publicidade de uma forma mais personalizada, medirmos a atividade no site e fornecermos funcionalidades e conteúdos personalizados a cada utilizador. Clique em baixo para consentir a utilização dos seus dados. Pode voltar às suas opções em qualquer momento.',
  );
  // Romanian.
  $body_options['ro'] = array(
    '1' => 'Noi și partenerii noștri folosim tehnologii, precum modulele cookie de pe site-ul nostru, pentru a ne personaliza conținutul și reclamele, pentru a oferi funcții pentru rețelele de socializare și pentru a ne analiza traficul. Faceți clic mai jos pentru a fi de acord cu utilizarea acestei tehnologii pe web. Vă puteți răzgândi și vă puteți modifica opțiunile privind aprobarea oricând, revenind la acest site.',
    '2' => 'Noi și partenerii noștri vă prelucrăm datele cu caracter personal folosind tehnologii precum modulele cookie pentru a transmite reclame, pentru a ne analiza traficul și pentru a vă asigura experiențe personalizate. Dumneavoastră puteți alege cine anume vă utilizează datele și în ce scop, iar după setarea preferințelor dvs., puteți reveni oricând pentru a efectua modificări.',
    '3' => 'Conținutul și informațiile de calitate pe care vi le oferim depind de veniturile pe care le obținem din publicitate. Noi și partenerii noștri utilizăm datele dvs. cu caracter personal pentru a transmite publicitate personalizată, pentru a măsura activitatea de pe site și pentru a vă oferi funcții și conținut personalizat. Faceți clic mai jos pentru a fi de acord cu utilizarea datelor dvs. Puteți reveni la opțiunile alese de dvs. oricând.',
  );
  // Finish.
  $body_options['fi'] = array(
    '1' => 'Me ja yhteistyökumppanimme käytämme evästeitä ja vastaavaa teknologiaa yksilöidäksemme sisältöä ja mainoksia, hyödyntääksemme sosiaalisen median toimintoja ja analysoidaksemme kävijätietoja. Napsauta painiketta suostuaksesi tämän teknologian käyttöön internetin selailussa. Voit muuttaa mieltäsi milloin vain ja valita eri suostumusvaihtoehdon palaamalla tälle sivustolle.',
    '2' => 'Me ja yhteistyökumppanimme käsittelemme henkilökohtaisia tietojasi käyttämällä evästeitä ja vastaavaa teknologiaa. Niitä hyödynnetään mainonnassa, kävijätietojen analyysissa ja yksilöityjen kokemuksien tarjoamisessa. Voit itse valita, kuka käyttää tietojasi ja mihin tarkoitukseen. Valinnan tehtyäsi voit milloin vain palata muuttamaan asetuksiasi.',
    '3' => 'Meidän tuottamamme laadukas sisältö ja informaatio rahoitetaan mainonnasta saaduilla tuloilla. Me ja yhteistyökumppanimme käytämme henkilökohtaisia tietojasi kohdennettuun mainontaan, sivustokäytön aktiivisuuden mittaamiseen ja yksilöityjen ominaisuuksien ja sisältöjen tarjoamiseen käyttäjille. Napsauta painiketta suostuaksesi tietojesi käyttöön. Voit palata muuttamaan valintojasi milloin vaan.',
  );
  // Polish.
  $body_options['pl'] = array(
    '1' => 'Na potrzeby naszej witryny korzystamy z plików cookie w celu personalizacji treści i reklam, udostępniania funkcji mediów społecznościowych oraz analizowania ruchu na stronie. Kliknij poniższy przycisk, aby wyrazić zgodę na korzystanie z tej technologii w Internecie. W każdej chwili możesz zmienić zdanie i wrócić na tę stronę, aby cofnąć zgodę.',
    '2' => 'Przetwarzamy Twoje dane osobowe przy użyciu plików cookie w celu prezentacji reklam, analizy ruchu na stronie i personalizacji treści. Możesz zadecydować o tym, kto i w jakim celu będzie korzystał z Twoich danych, a po skonfigurowaniu ustawień powrócić na tę stronę w każdej chwili, aby dokonać zmian.',
    '3' => 'Jakość treści i informacji, które zapewniamy, zależy od wysokości dochodu generowanego dzięki reklamom. Korzystamy z Twoich danych osobowych, aby prezentować spersonalizowane reklamy, mierzyć aktywność na stronie oraz udostępniać przystosowane do indywidualnych potrzeb funkcje i treści. Kliknij poniższy przycisk, aby wyrazić zgodę na korzystanie z Twoich danych. W każdej chwili możesz zmienić swoją decyzję.',
  );
  // Slovak.
  $body_options['sk'] = array(
    '1' => 'Spolu s našimi partnermi používame na našej stránke technológie, ako napríklad súbory cookie, prostredníctvom ktorých vám prispôsobujeme obsah a reklamy, poskytujeme funkcie sociálnych sietí a analyzujeme jej návštevnosť. Kliknutím nižšie odsúhlasíte používanie týchto technológií na celej našej webovej stránke. Súhlas môžete kedykoľvek stiahnuť a voľby súhlasu kedykoľvek zmeniť návratom na túto stránku.',
    '2' => 'Spolu s našimi partnermi spracovávame vaše osobné údaje pomocou technológií, ako napríklad súborov cookie, aby sme mohli zobrazovať reklamy, analyzovať návštevnosť našej stránky a prispôsobovať vám zážitky, ktoré prinášame. Môžete si vybrať, kto a na aké účely používa vaše údaje, a aj po tom, ako sa rozhodnete, môžete kedykoľvek svoj výber zmeniť.',
    '3' => 'Kvalita obsahu a informácií, ktoré vám poskytujeme, závisí od našich príjmov z reklamy. Spolu s našimi partnermi používame vaše osobné údaje, aby sme vám mohli prispôsobovať reklamy, merať aktivitu na webovej stránke a poskytovať vám funkcie a obsah prispôsobené na mieru. Kliknutím nižšie poskytnete súhlas s používaním vašich údajov. Svoje rozhodnutie môžete kedykoľvek zmeniť.',
  );
  // Swedish.
  $body_options['sv'] = array(
    '1' => 'Vi och våra partners använder teknik så som cookies på vår webbplats för att personifiera innehåll och annonser, tillhandahålla funktioner för sociala medier samt analysera vår trafik. Klicka nedan för att godkänna användningen av denna teknik över hela webben. Du kan ångra dig och ändra dina samtyckesval när som helst genom att återvända till den här webbplatsen.',
    '2' => 'Vi och våra partners behandlar dina personuppgifter med hjälp av teknik så som cookies för att kunna tillhandahålla reklam, analysera vår trafik samt leverera anpassade upplevelser för dig. Du har ett val i vem som använder din data och för vilka ändamål, och kan när som helst efter att du har ställt in dina preferenser komma tillbaka för att göra ändringar.',
    '3' => 'Kvalitetsinnehållet och informationen vi tillhandahåller beror på de intäkter vi genererar från annonsering. Vi och våra partners använder dina personuppgifter för att kunna erbjuda personlig annonsering, mäta aktivitet på webbplatsen samt leverera personliga funktioner och innehåll till dig. Klicka nedan för att godkänna användningen av dina uppgifter. Du kan när som helst återkomma till dina val.',
  );
  // Russian.
  $body_options['ru'] = array(
    '1' => 'Мы и наши партнёры исполузем онлайн технологии, такие как куки, для персонализации контента и рекламы, предоставления функций социальных сетей и анализа нашего трафика. Нажмите для согласия на использование этих онлайн-технологий. Вы сможете изменить свой выбор и отказаться от согласия в любой момент, вернувшись на этот сайт.',
    '2' => 'Мы и наши партнеры обрабатываем ваши персональные данные с использованием таких технологий, как куки, чтобы добавлять в контент рекламу, анализировать трафик и предоставлять Bам более персонифицированный подход. Вы можете выбрать, кто и для каких целей сможет использовать ваши персональные данные, и после настройки Bаших предпочтений Вы сможете вернуться сюда в любой момент, если решите внести изменения.',
    '3' => 'Качественный контент и информация, которые мы Bам предоставляем, зависят от дохода, который мы получаем от онлайн-рекламы. Мы и наши партнеры используем ваши личные данные, чтобы предлагать более персонализированную рекламу, измерять активность пользователей на сайте и предоставлять Bам специальные функции и контент. Нажмите, чтобы согласиться на использование Bаших личных данных. Вы можете изменить свой выбор в любой момент.',
  );
  // Arabic.
  $body_options['ar'] = array(
    '1' => 'نستخدم نحن وشركاؤنا ملفات التعريف على موقعنا بهدف تخصيص المحتوى والإعلانات المبوبة. كما يمكننا عن طريقها تزويد الصفحة بأيقونات وسائل التواصل الاجتماعي المختلفة. باستخدام هذه الخاصية يمكننا السيطرة على انتقاء زوار الصفحة.أنقر أدناه للموافقة على استخدام هذه التقنية عبر الويب يمكنك تغيير قرارك عبر تغيير خيارات الموافقة الموجودة على الموقع في جميع الأوقات.',
    '2' => 'نحن وشركاؤنا نعالج البيانات الشخصية عن طريق استخدام التكنولوجيا المعلوماتية للتعرف على ما يحلوا لزوار الصفحة مما يساعد الفريق الصحفي على اتخاذ قراراته التحريرية. ولديك مطلق الحرية في اختيار من يستخدم بياناتك ولأي هدف. كما يمكنك العودة لتغيير بياناتك الشخصية على الصفحة في أي وقت أردت',
    '3' => 'تعتمد جودة المعلومات التي نقدمها لك على الأرباح التي نحققها من الإعلانات. نحن وشركاؤنا نستخدم بياناتك الشخصية لتزويدك بالإعلانات التي تهمك ومعرفة الموضوعات التي تهمك على موقعنا ونسبة نشاطك. إذا وافقت على استخدام بياناتك الشخصية للأهداف السابقة فقط أنقر أدناه، يمكنك تغيير اختيارك في أي وقت.',
  );
  // Farsi.
  $body_options['fa'] = array(
    '1' => 'ما و شرکایمان از فناوری کوکی برروی سایتمان استفاده می کنیم و به این ترتیب محتوا و تبلیغات متناسب شخصیت شما ارائه خواهد شد. برای اعلام موافقت خود در زیر کلیک می کنید. شما می‌توانید این تنظیمات را هر موقع که خواستید تغییر دهید.',
    '2' => 'ما و شرکایمان داده‌های شخصی را با استفاده از فناوری کوکی بررسی می کنیم تا از آن برای تبلیغ، تحلیل ترافیک سایت و ارائه بهتر اطلاعات به شما استفاده کنیم. شما امکان تعیین اینکه چه کسی از داده های شما برای چه هدفی استفاده کند را خواهید داشت و می‌توانید این تنظیمات را در آینده تغییر دهید.',
    '3' => 'کیفیت مطالبی که به شما ارائه می کنیم به درآمدی که از راه تبلیغات کسب می کنیم، بستگی خواهد شد. ما و شرکایمان از داده های شخصی شما برای ارائه تبلیغات متناسب با وضعیت شما و بررسی میزان فعالیت بر روی وبسایت و ارائه محتوای متناسب با حال شما استفاده خواهیم کرد. برای اعلام موافقت خود در زیر کلیک کنید. هر گاه خواستید می‌توانید در انتخاب خود تجدیدنظر کنید.'
  );

  $ret = isset( $body_options[$lang] ) ? $body_options[$lang] : array( '1' => t( 'There are no body text options for the <strong>@lang</strong> language.', array( '@lang' => $lang ) ) );

  return $ret;

}
